@@ -1,6 +1,6 @@
 package CPAN::InGit;
 
-our $VERSION = '0.000_002'; # TRIAL VERSION
+our $VERSION = '0.001'; # VERSION
 # ABSTRACT: Manage custom CPAN trees to pin versions for your projects
 
 use Git::Raw::Repository;
@@ -280,16 +280,70 @@ CPAN::InGit - Manage custom CPAN trees to pin versions for your projects
 
 =head1 SYNOPSIS
 
-  my $cpan_repo= CPAN::InGit->new(repo => $path_to_git_repo);
-  my $mirror_tree= $cpan_repo->branch_mirror($git_branch_name);
-  # (all interesting methods are found on Mirror objects)
+Using the module:
+
+  my $git_repo= Git::Raw::Repository->discover($repo_path // getcwd);
+  my $cpan_repo= CPAN::InGit->new(git_repo => $git_repo);
+  
+  # Create a mirror of public CPAN
+  # Setting "upstream_url" creates a partial mirror which advertises all
+  # current public CPAN versions of modules, and fetches dists on demand
+  # and commits them to that branch, as a cache.
+  $cpan_repo->create_archive_tree('www_cpan_org', upstream_url => 'https://www.cpan.org');
+  
+  # Create a branch to be the per-application tree of modules.  Configure
+  # it to "import_modules" from branch "www_cpan_org".
+  $cpan_repo->create_archive_tree('my_app',
+    default_import_sources => ['www_cpan_org'],
+    corelist_perl_version => '5.026003',
+  );
+  
+  # This pulls modules Catalyst and DBIx::Class from the www_cpan_org branch
+  # (which fetches and commits on demand) and then adds them to the package
+  # index of branch 'my_app'.
+  my $app_pan= $cpan_repo->get_archive_tree('my_app');
+  $app_pan->import_modules({
+    'Catalyst' => 0,
+    'DBIx::Class' => 0,
+  });
+  
+  # Commit the changes to branch 'my_app'
+  $app_pan->commit("Added Catalyst and DBIx::Class");
+  
+  # This only pulls Log::Any, because the versions of Catalyst and DBIx::Class
+  # are already satisfied, even if new versions of DBIx::Class were available,
+  # and even if those new versions were in branch 'www_cpan_org'.
+  # The versions are pinned until you request a newer version.
+  $app_pan->import_modules({
+    'Catalyst' => 0,
+    'DBIx::Class' => 0,
+    'Log::Any' => 1,
+  });
+
+Using the command line to do the same as above:
+
+  mkdir localpan && cd localpan && git init
+  cpangit-create --upstream_url=https://www.cpan.org www_cpan_org
+  cpangit-create --from=www_cpan_org --corelist=v5.26 my_app
+  cpangit-add --branch=my_app Catalyst DBIx::Class
+  cpangit-add --branch=my_app Catalyst DBIx::Class Log::Any
+  cpangit-server -l http://localhost:3000 &
+  cpanm -M http://localhost:3000/my_app/ Catalyst DBIx::Class
 
 =head1 DESCRIPTION
 
-C<CPAN::InGit> is a concept that your entire CPAN mirror (or maybe more correctly a
-DarkPAN) lives within a Git repository.  You designate a branch for each of your perl
-environments (such as one branch per application) and that branch contains B<ONLY> the dist
-tarballs used by that project, and an index of the packages within.
+B<WARNING> This module is in an early state of development, and the API is not final.
+
+C<CPAN::InGit> is a concept that instead of using Carton and a cpanfile.spanshot to request
+an exact list of modules for your project, you store the exact list in a Git repo and then serve
+that as a CPAN mirror to your CPAN client as if these are the only versions of modules that
+exist.  You can then use any CPAN client you like without fussing with where it will install the
+modules or how it will decide when to upgrade versions of dependencies.
+
+Eventually, I plan to have functionality to help "curate" a collection of CPAN modules, such as
+applying patches for known issues in modules, ensuring application branches upgrade to those
+patched versions, upgrading back to the public CPAN verison when the fix gets picked up by the
+primary author, or identifying when dependencies have CVEs that require an upgrade.
 
 =head3 Features
 
@@ -297,35 +351,34 @@ tarballs used by that project, and an index of the packages within.
 
 =item *
 
-It's your own private CPAN (DarkPAN) with all the benefits that entails.  (such as private
-dists or patching public dists)
+It's your own private CPAN (DarkPAN) with all the benefits that entails.
+(such as private distributions or patching public distributions)
 
 =item *
 
-The data is stored in Git, so it's version controlled and compressed.  This module reads
-directly from the Git repo storage without needing a checkout.
+By hosting CPAN modules on your own infrastructure, you can avoid hammering public CPAN with
+your CI/CD builds every time you push a commit.
+
+=item *
+
+The data is stored in Git, so it's version controlled and compressed.
+You can revert to a previous environment for your application with a simple "git revert".
 
 =item *
 
 The server serves each B<branch> as its own mirror URL, so it's actually like an unlimited
-number of DarkPANs hosted on the same server.  Each branch indexes only the dist files you
-have added to that branch, and only one version per dist.
+number of DarkPANs hosted on the same server.  You can reference the server sub-path with
+your project's Dockerfile like C<< cpanm -M http://ingit-server.local/my_app_branch/ >>.
 
 =item *
 
-There is a web interface that helps you pull new versions of dists from public CPAN, review
-the changes and compare diffs of the module code, chain-pull new dependencies, and commit the
-new dist versions into a branch.  The web interface also helps you apply patches to public
-dists and maintains the history of those patches.
+This module reads directly from the Git repo storage without needing a checkout.
+You can point the server at the same repository being hosted by
+L<Gitea|https://about.gitea.com/products/gitea/>.
 
 =item *
 
-You can revert to a previous environment for your application with a simple "git revert".
-(or use the web interface)
-
-=item *
-
-Removes the need for cpanfile.snapshot or carton, because now the DarkPAN mirror is versioning
+Removes the need for cpanfile.snapshot or Carton, because now the DarkPAN mirror is versioning
 your environment for each application.
 
 =back
@@ -417,7 +470,7 @@ L</upstream_mirrors>.
 
 =head1 VERSION
 
-version 0.000_002
+version 0.001
 
 =head1 AUTHOR
 
