@@ -1,5 +1,5 @@
 package CPAN::InGit::ArchiveTree;
-our $VERSION = '0.000_002'; # TRIAL VERSION
+our $VERSION = '0.001'; # VERSION
 # ABSTRACT: An object managing a CPAN file structure in a Git Tree
 
 
@@ -50,7 +50,9 @@ sub _unpack_config($self, $config) {
 
 sub _pack_config($self, $config) {
    for (qw( default_import_sources corelist_perl_version canonical_url )) {
-      $config->{$_}= $self->$_;
+      my $val= $self->$_;
+      $val= "$val" if ref $val eq 'version';
+      $config->{$_}= $val;
    }
 }
 
@@ -66,7 +68,7 @@ sub write_config($self) {
 
 has canonical_url          => ( is => 'rw' );
 has default_import_sources => ( is => 'rw' );
-has corelist_perl_version  => ( is => 'rw', default => '5.008000' );
+has corelist_perl_version  => ( is => 'rw', default => '5.008009' );
 
 
 sub package_details_blob($self) {
@@ -252,11 +254,13 @@ sub _merge_prereqs($self, $reqs, $new_reqs) {
 }
 
 sub import_modules($self, $reqs, %options) {
+   # Determine what module versions were available for the app's version of perl.
    require Module::CoreList;
-   # None of our projects use older than 5.24, so no need to pull in dual-life modules
-   # if perl 5.24 had a sufficient version.  Set this to match your oldest production perl.
-   my $perl_v= $options{corelist_perl_version} // $self->corelist_perl_version // '5.024';
-   my $corelist= Module::CoreList::find_version($perl_v);
+   my $perl_v= $options{corelist_perl_version} // $self->corelist_perl_version;
+   $perl_v= version->parse($perl_v)->numify;
+   my $corelist= Module::CoreList::find_version($perl_v)
+      or carp "No corelist for $perl_v";
+
    my $sources= $options{sources} // $self->default_import_sources;
    my $prereq_phases= [qw( configure build runtime test )];
    my $prereq_types=  [qw( requires )];
@@ -506,7 +510,7 @@ working branch, the index also gets updated.
 
 =head1 VERSION
 
-version 0.000_002
+version 0.001
 
 =head1 AUTHOR
 
