@@ -1,5 +1,5 @@
 package CPAN::InGit::Server;
-our $VERSION = '0.000_002'; # TRIAL VERSION
+our $VERSION = '0.001'; # VERSION
 # ABSTRACT: A Mojolicious::Controller that serves the ArchiveTrees from a git repo
 
 
@@ -66,7 +66,8 @@ sub mount($class, $base_route, $cpan_repo, %options) {
    $base_route= $base_route->to(namespace => '', controller => $class, cpan_repo => $cpan_repo, %options);
    my $tree_route= $atree? $base_route
       : $base_route->any('/:branch_name');
-   $tree_route->get('/modules/02packages.details.txt.gz')->to(action => 'serve_package_details');
+   $tree_route->get('/modules/02packages.details', [ format => ['txt','txt.gz'] ])
+      ->to(action => 'serve_package_details');
    $tree_route->get('/authors/id/*author_path')->to(action => 'serve_author_file');
 }
 
@@ -82,7 +83,11 @@ sub check_branch_exists($c) {
 
 sub serve_package_details($c) {
    return undef unless $c->check_branch_exists;
-   $c->render_gzipped($c->archive_tree->package_details_blob->content, '02packages.details.txt.gz');
+   my $blob= $c->archive_tree->package_details_blob;
+   $c->respond_to(
+      txt      => sub { $c->render(text => $blob->content) },
+      'txt.gz' => sub { $c->render_gzipped($blob->content, '02packages.details.txt.gz') },
+   );
 }
 
 
@@ -192,7 +197,7 @@ It returns true, or sets a 404 error and returns undef, and can be used as C<< -
 
 =head2 serve_package_details
 
-Serve C<< modules/02packages.details.txt.gz >>.
+Serve C<< modules/02packages.details.txt[.gz] >>.
 
 =head2 serve_author_file
 
@@ -242,7 +247,7 @@ selector portion of the paths.
 
 =head1 VERSION
 
-version 0.000_002
+version 0.001
 
 =head1 AUTHOR
 
